From f3b82bacb0572389b25a96dd379c9bb77f422251 Mon Sep 17 00:00:00 2001
From: ABW <andrzejl@syncad.com>
Date: Mon, 27 Jul 2020 20:02:24 +0200
Subject: [PATCH] [ABW]: [Fix] it is better to save all files before commit :o)

---
 hive/db/schema.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/hive/db/schema.py b/hive/db/schema.py
index 939ca8260..e5af862ca 100644
--- a/hive/db/schema.py
+++ b/hive/db/schema.py
@@ -587,9 +587,9 @@ def setup(db):
     db.query_no_return(sql)
 
     sql = """
-        DROP VIEW IF EXISTS public.vw_hive_posts;
+        DROP VIEW IF EXISTS public.hive_posts_view;
 
         CREATE OR REPLACE VIEW public.vw_hive_posts
           AS
           SELECT hp.id,
             hp.community_id,
@@ -587,9 +587,9 @@ def setup(db):
 
-        CREATE OR REPLACE VIEW public.vw_hive_posts
+        CREATE OR REPLACE VIEW public.hive_posts_view
           AS
           SELECT hp.id,
-- 
GitLab